@@ -21,7 +21,7 @@ END_SYNOPSIS
 my $constructor = <<'END_CONSTRUCTOR_CODE_SAMPLE';
     my $compiler = MyCompiler->SUPER::new(
         parent     => $my_query,
-        searchable => $searcher,
+        searcher   => $searcher,
         similarity => $sim,        # default: undef
         boost      => undef,       # default: see below
     );
@@ -63,7 +63,7 @@ Clownfish::Binding::Perl::Class->register(
 
 __COPYRIGHT__
 
-Copyright 2005-2010 Marvin Humphrey
+Copyright 2005-2011 Marvin Humphrey
 
 This program is free software; you can redistribute it and/or modify
 under the same terms as Perl itself.
